/********************************************************************
 * tile map management definitions
 *
 * written by Doug Lanford, opus@opusgames.com
 * for more info, go to www.opusgames.com
 *
 * This file is provided as freeware
 *******************************************************************/

#ifndef	_TILEMAP_H
#define	_TILEMAP_H

#include "types.h"
#include "gba_bkg.h"


// this struct is used to store info about a background (where its tiles are located,
// where the tile map is located, its scroll settings, etc)
typedef struct BackgroundStruct
{
	u32		*pTiles;	// address where the tiles for this background are located
	u16		*pMap;		// address where the tile map for this background are located

	u16		scrollX;	// scroll settings for this background
	u16		scrollY;

	u8		bkgNum;		// which hardware background is this struct associated with (0..3)
} BackgroundStruct;



/*************************************************************************************************
 * initialize a background
 *
 * IN:		bkgNum - which background is being initialized (0..3)
 * 			tileBlock - character block number (0..3) - what block in VRAM the tiles for the background go
 * 			mapBlock - screen block number (0..31) - what block in VRAM the tile map will go
 * 			priority - priority setting (0..3)
 *          flags - settings flags (BKG_MOSAIC, BKG_COLOR_MODE, BKG_WRAP)
 * 			size - tile map size (0..3) - see below
 *
 * OUT:		hardware register for the background is set
 * 			pBkg - ptr to a BackgroundStruct... struct is inited
 *
 * NOTES:	1) this routine does NOT turn on the display of the tile map in the display mode register
 * 			2) possible size settings:
 *				0 = 32x32 tiles, or 16x16 if rotating background
 *				1 = 64x32 tiles, or 32x32 if rotating background
 *				2 = 32x64 tiles, or 64x64 if rotating background
 *				3 = 64x64 tiles, or 128x128 if rotating background
 *			3) flags:
 * 				BKG_MOSAIC - if set, the background uses mosaic mode
 * 				BKG_COLOR_MODE - if set, the background uses a 256 color palette (default is 16 color palettes)
 * 				BKG_WRAP - if set, the background wraps at the edges (for rotating backgrounds)
 *************************************************************************************************/
extern void Bkg_Init (u8 bkgNum, u8 tileBlock, u8 mapBlock, u8 priority, u16 flags, u8 size, BackgroundStruct *pBkg);





#endif

