/************************************************************************
 * collision routines
 *
 * written by Doug Lanford, opus@opusgames.com
 * for more info, go to www.opusgames.com
 *
 * This file is provided as freeware
 ***********************************************************************/

#include "collide.h"
#include "object.h"
#include "ship.h"
#include "powerup.h"


extern s24f8_vect2D shipSize;
extern s24f8_vect2D powerupSize;

/*****************************************************
 * collide a point with all the ai ships (hardcoded
 * for current ship size, and just does a rectangular
 * check... nothing fancy!)
 *
 * IN: 		point to collide against
 *
 * RETURNS:	non-zero if a collision occured
 ****************************************************/
u32 Collide_PointToShip (s24f8_vect2D *pPos)
{
u16 curObj;
ShipStruct *pShip;

	// start at top of ship object list
	curObj = activeObjects[OBJECT_SHIP];
	while (curObj != OBJECT_NULL)
	{	// walk through all active objects
		pShip = (ShipStruct *)&objectBuffer[curObj];

		if ((pShip->shipType != SHIP_PLAYER) && (pShip->life > 0))
		{
			if ((pPos->x > pShip->pos.x - shipSize.x) && (pPos->x < pShip->pos.x + shipSize.x)
				&& (pPos->y > pShip->pos.y - shipSize.y) && (pPos->y < pShip->pos.y + shipSize.y))
			{	// collided
					pShip->life--;
					if (pShip->life <= 0)
					{
						pShip->life = 0;
						pShip->timer = 0;
					}
					return(1);
			}
		}

		curObj = pShip->next;
	}

	return(0);
}


/*****************************************************
 * collide a point with all the powerups (hardcoded
 * for current ship size, and just does a rectangular
 * check... nothing fancy!)
 *
 * IN: 		point to collide against
 *
 * RETURNS:	number of points the powerup returns
 ****************************************************/
u32 Collide_PointToPowerup (s24f8_vect2D *pPos)
{
u16 curObj;
PowerupStruct *pPowerup;

	// start at top of ship object list
	curObj = activeObjects[OBJECT_POWERUP];
	while (curObj != OBJECT_NULL)
	{	// walk through all active objects
		pPowerup = (PowerupStruct *)&objectBuffer[curObj];

		if (pPowerup->health > 0)
		{
			if ((pPos->x > pPowerup->pos.x - powerupSize.x) && (pPos->x < pPowerup->pos.x + powerupSize.x)
				&& (pPos->y > pPowerup->pos.y - powerupSize.y) && (pPos->y < pPowerup->pos.y + powerupSize.y))
			{	// collided
				curObj = pPowerup->health;
				pPowerup->health = 0;	// tell the powerup to go away!
				return(curObj);
			}
		}

		curObj = pPowerup->next;
	}

	return(0);
}


