/*****************************************************************
 * computer controlled ship game object
 *
 * written by Doug Lanford, opus@opusgames.com
 * for more info, go to www.opusgames.com
 *
 * This file is provided as freeware
 ****************************************************************/

#ifndef _SHIP_H
#define	_SHIP_H

#include "types.h"
#include "math.h"
#include "object.h"

#define	SHIP_ACCEL	0x04

typedef enum eShipTypes
{
	SHIP_PLAYER,
	SHIP_CHASER,
	SHIP_RANDOMWALK,
	SHIP_ZIGZAG,

	NUM_SHIP_TYPES,
} eShipTypes;

// player object struct
typedef struct ShipStruct
{
	OBJECT_HEADER	// object system data

	s24f8_vect2D	pos;	// world position of the player
	s24f8_vect2D 	speed; 	// current speed (vector)

	ANGLE 			shipAngle;		// current rotation angle
	ANGLE			targetAngle;
	ANGLE			speedAngle;		// angle of our travelling speed

	s16				life;			// how much health the ship has

	s24f8 			speedMag;		// current speed (magnitude)
	s24f8 			targetSpeed;	// speed we are accelerating to
	s24f8_vect2D	addVelVect;		// some additional speed in some cases

	u16				shipType;	// type of ship
	u16				flags;		// some bit flags

	s24f8			shotTimer;		// time till we can fire another bullet
	s24f8			timer;		// timer

	u8				shieldCycle;	// where in the shield color cycle we are

} ShipStruct;


// base info about each type of ship
typedef struct ShipSetupStruct
{
	s16				maxLife;		// max amount of damage the ship can take
	u16				tile;			// what tile it uses for display
	s24f8			maxSpeed;		// this type's maximum speed
	s24f8			accel;			// how fast the ship accelerates
} ShipSetupStruct;


/******************************************************************
 * init the ship setups
 *****************************************************************/
extern void Ship_InitSystem (void);


/******************************************************************
 * launch a new ship object
 *
 * IN:		position of the ship
 * 			type of ship
 *
 * RETURNS:	ptr to a new ship object
 *****************************************************************/
extern ShipStruct *Ship_New (s24f8_vect2D *pPos, u16 type);


/******************************************************************
 * update a ship object
 *****************************************************************/
extern u32 Ship_Update (ObjectStruct *pObj);


#endif

